UnknownError class

Represents an Unknown error.

Inheritance

Constructors

UnknownError(String message, {int? code})

Properties

code int?
The HTTP status code, if available.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
message String
A human-readable error message.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited