clearOtpError method
void
clearOtpError()
Clears the inline error when the user starts typing again.
Implementation
void clearOtpError() {
if (otpError == null) return;
otpError = null;
notifyListeners();
}
Clears the inline error when the user starts typing again.
void clearOtpError() {
if (otpError == null) return;
otpError = null;
notifyListeners();
}