lockedOut property
Set when the server locked the session after too many wrong codes. The dialog shows lockoutMessage and leaves, like the widget resets to its home screen.
Implementation
bool lockedOut = false;
Set when the server locked the session after too many wrong codes. The dialog shows lockoutMessage and leaves, like the widget resets to its home screen.
bool lockedOut = false;