rememberMeEnabled property
Dashboard "Remember me" option (from the resolved theme). When false the checkbox is never shown, the flag is never sent and nothing is stored on the device.
Implementation
final bool rememberMeEnabled;
Dashboard "Remember me" option (from the resolved theme). When false the checkbox is never shown, the flag is never sent and nothing is stored on the device.
final bool rememberMeEnabled;