AuthyoButtonShape enum
Button corner style (maps to buttonStyle: 1 rectangular, 2 rounded, 3 pill).
Values
- rectangular → const AuthyoButtonShape
-
const AuthyoButtonShape(1, 0) - rounded → const AuthyoButtonShape
-
const AuthyoButtonShape(2, 10) - pill → const AuthyoButtonShape
-
const AuthyoButtonShape(3, 22)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - radius → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromValue(
Object? raw) → AuthyoButtonShape
Constants
-
values
→ const List<
AuthyoButtonShape> - A constant List of the values in this enum, in order of their declaration.