AuthyoMainLayout enum

Horizontal alignment of the dialog content (maps to mainLayout).

Inheritance
Available extensions

Values

left → const AuthyoMainLayout
const AuthyoMainLayout(1)
center → const AuthyoMainLayout
const AuthyoMainLayout(2)
const AuthyoMainLayout(3)

Properties

crossAxis CrossAxisAlignment
no setter
hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
mainAxis MainAxisAlignment
no setter
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textAlign TextAlign
no setter
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(Object? raw) AuthyoMainLayout

Constants

values → const List<AuthyoMainLayout>
A constant List of the values in this enum, in order of their declaration.