fontFamily property
String?
get
fontFamily
Base font family applied to everything in the dialog.
Implementation
String? get fontFamily => theme.fontFamily;
Base font family applied to everything in the dialog.
String? get fontFamily => theme.fontFamily;