progress method
Progress indicator shown while a request is in flight.
Implementation
Widget progress() => SizedBox(
width: 28,
height: 28,
child: CircularProgressIndicator(strokeWidth: 2.5, color: theme.primary),
);
Progress indicator shown while a request is in flight.
Widget progress() => SizedBox(
width: 28,
height: 28,
child: CircularProgressIndicator(strokeWidth: 2.5, color: theme.primary),
);