User class

Represents the user object returned in the response.

Constructors

User({String? phone, String? userId, String? email, String? identity, String? displayName, String? channel})
User.fromJson(Map<String, dynamic> json)
factory

Properties

channel String?
Channel the identity was verified through (e.g. sms, google).
getter/setter pair
displayName String?
getter/setter pair
email String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
identity String?
getter/setter pair
phone String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userId String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited