VerifyOTPParams class

Constructors

VerifyOTPParams({String? maskId, String? otp, bool rememberMe = false})
VerifyOTPParams.fromJson(Map<String, dynamic> json)

Properties

hashCode int
The hash code for this object.
no setterinherited
maskId String?
getter/setter pair
otp String?
getter/setter pair
rememberMe bool
"Remember me" ticked; only honoured when the app enabled the option.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited