AuthyoSocialProvider enum
Social identity providers that Authyo can be configured with from the dashboard (Application → Social Media Login).
Values
- google → const AuthyoSocialProvider
-
const AuthyoSocialProvider('Google') - microsoft → const AuthyoSocialProvider
-
const AuthyoSocialProvider('Microsoft') - github → const AuthyoSocialProvider
-
const AuthyoSocialProvider('Github') - linkedin → const AuthyoSocialProvider
-
const AuthyoSocialProvider('LinkedIn') - apple → const AuthyoSocialProvider
-
const AuthyoSocialProvider('Apple') - unknown → const AuthyoSocialProvider
-
const AuthyoSocialProvider('Unknown')
Properties
- apiName → String
-
Provider name as the backend spells it (
Common.SocialMediaenum).final - hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- label → String
-
no setter
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromName(
String? name) → AuthyoSocialProvider
Constants
-
values
→ const List<
AuthyoSocialProvider> - A constant List of the values in this enum, in order of their declaration.