resendTimerSeconds property
Dashboard "resend button timer" (seconds, 0 = not set). Like the web widget it is sent to the server as the new expiry when resending and used as the countdown only when the server reply carries no expiry.
Implementation
final int resendTimerSeconds;