AuthyoEndpoints class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
normalizeBaseUrl(
String? url) → String -
Normalises a user supplied server URL ("https://host
:port" with or without a trailing slash) to no trailing slash.
Constants
- apiPath → const String
- OTP API (send / verify), relative to the server base URL.
- authLoginEndpoint → const String
- authLoginPath → const String
- Builds the provider authorization URL for a social login.
- baseUrlEndpoint → const String
- clientBaseUrlEndpoint → const String
- clientPath → const String
- Client / widget API (dialog configuration, social login).
- defaultBaseUrl → const String
-
Default server. Override per app with
AuthyoService.init(baseUrl: ...)(e.g. a staging or local instance). - mobileConfigEndpoint → const String
- mobileConfigPath → const String
- Returns design style, customization, enabled channels and social logins for the application identified by the clientId / clientSecret headers.
- oauthCallbackScheme → const String
- Custom URL scheme the OAuth callback redirects to on mobile.
- sendOtpEndpoint → const String
- verifyOtpEndpoint → const String