AuthyoResolvedTheme class
Non-nullable projection of an AuthyoTheme for use inside renderers.
Properties
- background → Color
-
no setter
- bodyText → String
-
no setter
- bodyTextColor → Color
-
no setter
-
no setter
-
no setter
-
no setter
-
no setter
- fontFamily → String?
-
no setter
- glassOpacity → double
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- headerText → String
-
no setter
- headerTextColor → Color
-
no setter
- hideBranding → bool
-
no setter
- inputBackground → Color
-
no setter
- inputBorder → Color
-
no setter
- inputRadius → double
-
Input corner radius: "Input Style" when set, else the button shape.
no setter
- inputText → Color
-
no setter
- inputUnderline → bool
-
no setter
-
logo
→ ImageProvider<
Object> ? -
no setter
- logoUrl → String?
-
no setter
- mainLayout → AuthyoMainLayout
-
no setter
- onSurface → Color
-
Text colour that is readable on surface.
no setter
- onSurfaceMuted → Color
-
Muted variant of onSurface for hints and secondary text.
no setter
- otpHidden → bool
-
no setter
- primary → Color
-
no setter
- privacyLink → String?
-
no setter
- rememberMeDays → int
-
no setter
- rememberMeEnabled → bool
-
no setter
- resendTimerConfigured → int
-
Dashboard resend timer as configured (0 = not set). Sent to the server
as the new expiry on resend, exactly like the web widget.
no setter
- resendTimerSeconds → int
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showBody → bool
-
no setter
- showHeader → bool
-
no setter
- showLogo → bool
-
no setter
-
no setter
-
no setter
-
no setter
-
no setter
- surface → Color
-
no setter
- termsLink → String?
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited