models/widget_config library
Classes
- AuthyoSocialLogin
- One social login button as configured on the dashboard.
- AuthyoWidgetConfig
-
Remote configuration for the built-in dialog, as returned by
GET /api/v1/authyoclient/mobileconfig.
Enums
- AuthyoSocialProvider
- Social identity providers that Authyo can be configured with from the dashboard (Application → Social Media Login).